@@ -24,11 +24,7 @@
 #include <libgdamm.h>
 #include <libglom/connectionpool_backends/backend.h>
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
-
-#ifndef GLOM_ENABLE_SQLITE
-# error The Glom <sqlite.h> backend has been included even though sqlite support is disabled
-#endif
+#include <libglom/libglom_config.h>
 
 namespace Glom
 {
@@ -41,39 +37,33 @@ class Sqlite : public Backend
 public:
   Sqlite();
 
-  void set_database_directory_uri(const std::string& directory_uri);
-  const std::string& get_database_directory_uri() const;
-
 private:
   virtual Field::sql_format get_sql_format() const { return Field::SQL_FORMAT_SQLITE; }
   virtual bool supports_remote_access() const { return false; }
-  virtual Glib::ustring get_string_find_operator() const { return "LIKE"; }
+  virtual Gnome::Gda::SqlOperatorType get_string_find_operator() const { return Gnome::Gda::SQL_OPERATOR_TYPE_LIKE; }
+  virtual const char* get_public_schema_name() const { return "main"; }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
   bool add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, GdaMetaTableColumn* column, unsigned int i, std::auto_ptr<Glib::Error>& error);
   bool add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, const sharedptr<const Field>& column, unsigned int i, std::auto_ptr<Glib::Error>& error);
 
-  typedef std::vector<Glib::ustring> type_vecStrings;
-  //typedef std::vector<sharedptr<const Field> > type_vecFields;
+  typedef std::vector<Glib::ustring> type_vec_strings;
+  //typedef std::vector<sharedptr<const Field> > type_vec_fields;
   typedef std::map<Glib::ustring, sharedptr<const Field> > type_mapFieldChanges;
 
-  bool recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecStrings& fields_removed, const type_vecConstFields& fields_added, const type_mapFieldChanges& fields_changed, std::auto_ptr<Glib::Error>& error);
+  bool recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_strings& fields_removed, const type_vec_const_fields& fields_added, const type_mapFieldChanges& fields_changed, std::auto_ptr<Glib::Error>& error);
 
   virtual bool add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const sharedptr<const Field>& field, std::auto_ptr<Glib::Error>& error);
   virtual bool drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const Glib::ustring& field_name, std::auto_ptr<Glib::Error>& error);
-  virtual bool change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error);
-#endif
+  virtual bool change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields, std::auto_ptr<Glib::Error>& error);
 
   virtual Glib::RefPtr<Gnome::Gda::Connection> connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error);
 
   /** Creates a new database.
    */
-#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool create_database(const Glib::ustring& database_name, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<Glib::Error>& error);
-#endif
 
-private:
-  std::string m_database_directory_uri;
+  virtual bool save_backup(const SlotProgress& slot_progress, const Glib::ustring& username, const Glib::ustring& password, const Glib::ustring& database_name);
+  virtual bool convert_backup(const SlotProgress& slot_progress, const std::string& base_directory, const Glib::ustring& username, const Glib::ustring& password, const Glib::ustring& database_name);
 };
 
 } //namespace ConnectionPoolBackends
@@ -81,4 +71,3 @@ private:
 } //namespace Glom
 
 #endif //GLOM_BACKEND_SQLITE_H
-
