@@ -23,7 +23,7 @@
 
 #include <glibmm/ustring.h>
 #include <map>
-#include <glom/libglom/sharedptr.h>
+#include <libglom/sharedptr.h>
 
 namespace Glom
 {
@@ -78,8 +78,12 @@ public:
    */
   void set_title_original(const Glib::ustring& title);
 
+  //TODO: Rename to set_title_translation()?
   void set_translation(const Glib::ustring& locale, const Glib::ustring& translation);
   Glib::ustring get_translation(const Glib::ustring& locale) const;
+  
+  /// Clear the original title and any translations of the title.
+  void clear_title_in_all_locales();
 
   typedef std::map<Glib::ustring, Glib::ustring> type_map_locale_to_translations;
 
@@ -129,7 +133,7 @@ public:
 
   static bool get_current_locale_not_original();
 
-protected:
+private:
 
   /** Get the locale used as the source language.
    * This is the language of the title that is used when there are no translations.
@@ -137,8 +141,10 @@ protected:
   static Glib::ustring get_original_locale();
 
 
-
+protected:
   enumTranslatableItemType m_translatable_item_type;
+
+private:
   Glib::ustring m_name; //Non-translated identifier;
   Glib::ustring m_title; //The original, untranslated (usually-English) title.
   type_map_locale_to_translations m_map_translations;
